* [patch 01/19] ACPI: Clear GPE before disabling it
@ 2006-12-19 20:56 akpm
2006-12-23 2:15 ` Len Brown
0 siblings, 1 reply; 4+ messages in thread
From: akpm @ 2006-12-19 20:56 UTC (permalink / raw)
To: lenb
Cc: linux-acpi, akpm, william.morrow, jordan.crouse, len.brown,
luming.yu, robert.moore
From: William Morrow <william.morrow@amd.com>
On some BIOSen, the GPE bit will remain set even if it is disabled,
resulting in a interrupt storm. This patch clears the bit before disabling
it.
Signed-off-by: William Morrow <william.morrow@amd.com>
Signed-off-by: Jordan Crouse <jordan.crouse@amd.com>
Cc: "Yu, Luming" <luming.yu@intel.com>
Cc: "Brown, Len" <len.brown@intel.com>
Cc: "Moore, Robert" <robert.moore@intel.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---
drivers/acpi/events/evgpe.c | 14 +++++++++++++-
1 files changed, 13 insertions(+), 1 deletion(-)
diff -puN drivers/acpi/events/evgpe.c~acpi-clear-gpe-before-disabling-it drivers/acpi/events/evgpe.c
--- a/drivers/acpi/events/evgpe.c~acpi-clear-gpe-before-disabling-it
+++ a/drivers/acpi/events/evgpe.c
@@ -677,10 +677,22 @@ acpi_ev_gpe_dispatch(struct acpi_gpe_eve
case ACPI_GPE_DISPATCH_METHOD:
/*
* Disable GPE, so it doesn't keep firing before the method has a
* chance to run.
*/
+ status = acpi_hw_clear_gpe(gpe_event_info);
+ if (ACPI_FAILURE(status)) {
+ ACPI_EXCEPTION((AE_INFO, status,
+ "Unable to clear GPE[%2X]",
+ gpe_number));
+ return_UINT32(ACPI_INTERRUPT_NOT_HANDLED);
+ }
+ /*
+ * Disable GPE, so it doesn't keep happen again.
+ */
+
status = acpi_ev_disable_gpe(gpe_event_info);
+
if (ACPI_FAILURE(status)) {
ACPI_EXCEPTION((AE_INFO, status,
"Unable to disable GPE[%2X]",
_
^ permalink raw reply [flat|nested] 4+ messages in thread* Re: [patch 01/19] ACPI: Clear GPE before disabling it
2006-12-19 20:56 [patch 01/19] ACPI: Clear GPE before disabling it akpm
@ 2006-12-23 2:15 ` Len Brown
2006-12-23 4:16 ` Andrew Morton
2006-12-24 22:43 ` Jordan Crouse
0 siblings, 2 replies; 4+ messages in thread
From: Len Brown @ 2006-12-23 2:15 UTC (permalink / raw)
To: akpm; +Cc: linux-acpi, william.morrow, jordan.crouse, luming.yu,
robert.moore
NAK
Per previous discussions, I continue to have no plans to apply this patch as it stands,
and am awaiting reply from the author if the latest ACPICA code
works properly on their machine without this patch.
thanks,
-Len
On Tuesday 19 December 2006 15:56, akpm@osdl.org wrote:
> From: William Morrow <william.morrow@amd.com>
>
> On some BIOSen, the GPE bit will remain set even if it is disabled,
> resulting in a interrupt storm. This patch clears the bit before disabling
> it.
>
> Signed-off-by: William Morrow <william.morrow@amd.com>
> Signed-off-by: Jordan Crouse <jordan.crouse@amd.com>
> Cc: "Yu, Luming" <luming.yu@intel.com>
> Cc: "Brown, Len" <len.brown@intel.com>
> Cc: "Moore, Robert" <robert.moore@intel.com>
> Signed-off-by: Andrew Morton <akpm@osdl.org>
> ---
>
> drivers/acpi/events/evgpe.c | 14 +++++++++++++-
> 1 files changed, 13 insertions(+), 1 deletion(-)
>
> diff -puN drivers/acpi/events/evgpe.c~acpi-clear-gpe-before-disabling-it drivers/acpi/events/evgpe.c
> --- a/drivers/acpi/events/evgpe.c~acpi-clear-gpe-before-disabling-it
> +++ a/drivers/acpi/events/evgpe.c
> @@ -677,10 +677,22 @@ acpi_ev_gpe_dispatch(struct acpi_gpe_eve
> case ACPI_GPE_DISPATCH_METHOD:
>
> /*
> - * Disable GPE, so it doesn't keep firing before the method has a
> + * Clear GPE, so it doesn't keep firing before the method has a
> * chance to run.
> */
> + status = acpi_hw_clear_gpe(gpe_event_info);
> + if (ACPI_FAILURE(status)) {
> + ACPI_EXCEPTION((AE_INFO, status,
> + "Unable to clear GPE[%2X]",
> + gpe_number));
> + return_UINT32(ACPI_INTERRUPT_NOT_HANDLED);
> + }
> + /*
> + * Disable GPE, so it doesn't keep happen again.
> + */
> +
> status = acpi_ev_disable_gpe(gpe_event_info);
> +
> if (ACPI_FAILURE(status)) {
> ACPI_EXCEPTION((AE_INFO, status,
> "Unable to disable GPE[%2X]",
> _
>
^ permalink raw reply [flat|nested] 4+ messages in thread* Re: [patch 01/19] ACPI: Clear GPE before disabling it
2006-12-23 2:15 ` Len Brown
@ 2006-12-23 4:16 ` Andrew Morton
2006-12-24 22:43 ` Jordan Crouse
1 sibling, 0 replies; 4+ messages in thread
From: Andrew Morton @ 2006-12-23 4:16 UTC (permalink / raw)
To: Len Brown
Cc: linux-acpi, william.morrow, jordan.crouse, luming.yu,
robert.moore
On Fri, 22 Dec 2006 21:15:50 -0500
Len Brown <lenb@kernel.org> wrote:
> NAK
>
> Per previous discussions, I continue to have no plans to apply this patch as it stands,
> and am awaiting reply from the author if the latest ACPICA code
> works properly on their machine without this patch.
>
Well I'm fed up with maintaining the thing in the presence of continuous
underlying churn and apparent non-communication from involved parties, so
I'll drop it.
>
> On Tuesday 19 December 2006 15:56, akpm@osdl.org wrote:
> > From: William Morrow <william.morrow@amd.com>
> >
> > On some BIOSen, the GPE bit will remain set even if it is disabled,
> > resulting in a interrupt storm. This patch clears the bit before disabling
> > it.
> >
> > Signed-off-by: William Morrow <william.morrow@amd.com>
> > Signed-off-by: Jordan Crouse <jordan.crouse@amd.com>
> > Cc: "Yu, Luming" <luming.yu@intel.com>
> > Cc: "Brown, Len" <len.brown@intel.com>
> > Cc: "Moore, Robert" <robert.moore@intel.com>
> > Signed-off-by: Andrew Morton <akpm@osdl.org>
> > ---
> >
> > drivers/acpi/events/evgpe.c | 14 +++++++++++++-
> > 1 files changed, 13 insertions(+), 1 deletion(-)
> >
> > diff -puN drivers/acpi/events/evgpe.c~acpi-clear-gpe-before-disabling-it drivers/acpi/events/evgpe.c
> > --- a/drivers/acpi/events/evgpe.c~acpi-clear-gpe-before-disabling-it
> > +++ a/drivers/acpi/events/evgpe.c
> > @@ -677,10 +677,22 @@ acpi_ev_gpe_dispatch(struct acpi_gpe_eve
> > case ACPI_GPE_DISPATCH_METHOD:
> >
> > /*
> > - * Disable GPE, so it doesn't keep firing before the method has a
> > + * Clear GPE, so it doesn't keep firing before the method has a
> > * chance to run.
> > */
> > + status = acpi_hw_clear_gpe(gpe_event_info);
> > + if (ACPI_FAILURE(status)) {
> > + ACPI_EXCEPTION((AE_INFO, status,
> > + "Unable to clear GPE[%2X]",
> > + gpe_number));
> > + return_UINT32(ACPI_INTERRUPT_NOT_HANDLED);
> > + }
> > + /*
> > + * Disable GPE, so it doesn't keep happen again.
> > + */
> > +
> > status = acpi_ev_disable_gpe(gpe_event_info);
> > +
> > if (ACPI_FAILURE(status)) {
> > ACPI_EXCEPTION((AE_INFO, status,
> > "Unable to disable GPE[%2X]",
> > _
> >
^ permalink raw reply [flat|nested] 4+ messages in thread* Re: ACPI: Clear GPE before disabling it
2006-12-23 2:15 ` Len Brown
2006-12-23 4:16 ` Andrew Morton
@ 2006-12-24 22:43 ` Jordan Crouse
1 sibling, 0 replies; 4+ messages in thread
From: Jordan Crouse @ 2006-12-24 22:43 UTC (permalink / raw)
To: Len Brown; +Cc: akpm, linux-acpi, william.morrow, luming.yu, robert.moore
On 22/12/06 21:15 -0500, Len Brown wrote:
> NAK
>
> Per previous discussions, I continue to have no plans to apply this patch as it stands,
> and am awaiting reply from the author if the latest ACPICA code
> works properly on their machine without this patch.
He is on vacation, I believe - probably won't hear from him until the
beginning of the year. I could try to re-create it, but I don't really know
what he did - so its probably faster to just wait.
Jordan
^ permalink raw reply [flat|nested] 4+ messages in thread
end of thread, other threads:[~2006-12-25 0:18 UTC | newest]
Thread overview: 4+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2006-12-19 20:56 [patch 01/19] ACPI: Clear GPE before disabling it akpm
2006-12-23 2:15 ` Len Brown
2006-12-23 4:16 ` Andrew Morton
@@ -677,10 +677,22 @@ acpi_ev_gpe_dispatch(struct acpi_gpe_eve
case ACPI_GPE_DISPATCH_METHOD:
/*
- * Disable GPE, so it doesn't keep firing before the method has a
+ * Clear GPE, so it doesn't keep firing before the method has a
* chance to run.
*/
2006-12-24 22:43 ` Jordan Crouse
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.